@@ -4,7 +4,7 @@ use warnings;
 use Moo;
 
 use utf8;
-use open ':std', ':encoding(utf8)';
+use open ':std', ':encoding(UTF-8)';
 use Encode qw(decode);
 use File::Find;
 use File::Spec;
@@ -15,7 +15,7 @@ use Carp;
 use List::Util qw(uniq);
 use POSIX qw(strftime);
 
-our $VERSION = '0.062'; # VERSION
+our $VERSION = '0.063'; # VERSION
 
 # ABSTRACT: The common base for Archive::BagIt. This is the module for experts. ;)
 
@@ -483,7 +483,7 @@ sub _build_manifest_files {
   my($self) = @_;
   my @manifest_files;
   foreach my $algo (@{$self->checksum_algos}) {
-    my $manifest_file = File::Spec->catdir($self->metadata_path, "manifest-$algo.txt");
+    my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$algo.txt");
     if (-f $manifest_file) {
       push @manifest_files, $manifest_file;
     }
@@ -495,7 +495,7 @@ sub _build_tagmanifest_files {
   my ($self) = @_;
   my @tagmanifest_files;
   foreach my $algo (@{$self->checksum_algos}) {
-    my $tagmanifest_file = File::Spec->catdir($self->metadata_path,"tagmanifest-$algo.txt");
+    my $tagmanifest_file = File::Spec->catfile($self->metadata_path,"tagmanifest-$algo.txt");
     if (-f $tagmanifest_file) {
       push @tagmanifest_files, $tagmanifest_file;
     }
@@ -508,8 +508,8 @@ sub _build_payload_files{
   my $payload_dir = $self->payload_path;
   my @payload=();
   File::Find::find( sub{
-    $File::Find::name = decode ('utf8', $File::Find::name);
-    $_ = decode ('utf8', $_);
+    $File::Find::name = decode ('UTF-8', $File::Find::name);
+    $_ = decode ('UTF-8', $_);
     if (-f $_) {
         my $rel_path=File::Spec->catdir($self->rel_payload_path,File::Spec->abs2rel($File::Find::name, $payload_dir));
         push(@payload,$rel_path);
@@ -531,8 +531,8 @@ sub _build_payload_files{
 sub __build_read_bagit_txt {
     my($self) = @_;
     my $bagit = $self->metadata_path;
-    my $file = File::Spec->catdir($bagit, "bagit.txt");
-    open(my $BAGIT, "<", $file) or croak("Cannot read '$file': $!");
+    my $file = File::Spec->catfile($bagit, "bagit.txt");
+    open(my $BAGIT, "<:encoding(UTF-8)", $file) or croak("Cannot read '$file': $!");
     my $version_string = <$BAGIT>;
     my $encoding_string = <$BAGIT>;
     close($BAGIT);
@@ -634,9 +634,9 @@ sub _parse_bag_info { # parses a bag-info textblob
 sub _build_bag_info {
     my ($self) = @_;
     my $bagit = $self->metadata_path;
-    my $file = File::Spec->catdir($bagit, "bag-info.txt");
+    my $file = File::Spec->catfile($bagit, "bag-info.txt");
     if (-e $file) {
-        open(my $BAGINFO, "<", $file) or croak("Cannot read $file: $!");
+        open(my $BAGINFO, "<:encoding(UTF-8)", $file) or croak("Cannot read $file: $!");
         my @lines;
         foreach my $line (<$BAGINFO>) {
             push @lines, $line;
@@ -653,8 +653,8 @@ sub _build_non_payload_files {
   my($self) = @_;
   my @non_payload = ();
   File::Find::find( sub{
-    $File::Find::name = decode('utf8', $File::Find::name);
-    $_=decode ('utf8', $_);
+    $File::Find::name = decode('UTF-8', $File::Find::name);
+    $_=decode ('UTF-8', $_);
     if (-f $_) {
         my $rel_path=File::Spec->catdir($self->rel_metadata_path,File::Spec->abs2rel($File::Find::name, $self->metadata_path));
         #print "pushing ".$rel_path." payload_dir: $payload_dir \n";
@@ -732,8 +732,8 @@ sub verify_bag {
     my $encoding = $self->bag_encoding(); # to call trigger
     my $baginfo = $self->verify_baginfo(); #to call trigger
     my $forced_fixity_alg = $self->forced_fixity_algorithm()->name();
-    my $fetch_file = File::Spec->catdir($self->metadata_path, "fetch.txt");
-    my $manifest_file = File::Spec->catdir($self->metadata_path, "manifest-$forced_fixity_alg.txt");
+    my $fetch_file = File::Spec->catfile($self->metadata_path, "fetch.txt");
+    my $manifest_file = File::Spec->catfile($self->metadata_path, "manifest-$forced_fixity_alg.txt");
     my $payload_dir   = $self->payload_path;
     my $return_all_errors = $opts->{return_all_errors};
 
@@ -774,7 +774,7 @@ sub calc_payload_oxum {
     my $octets=0;
     my $streamcount = scalar @payload;
     foreach my $local_name (@payload) {# local_name is relative to bagit base
-        my $file = File::Spec->catdir($self->bag_path(), $local_name);
+        my $file = File::Spec->catfile($self->bag_path(), $local_name);
         my $sb = stat($file);
         $octets += $sb->size;
     }
@@ -796,8 +796,8 @@ sub calc_bagsize {
 sub create_bagit {
     my($self) = @_;
     my $metadata_path = $self->metadata_path();
-    my $bagit_path = File::Spec->catdir( $metadata_path, "bagit.txt");
-    open(my $BAGIT, ">", $bagit_path) or croak("Can't open $bagit_path for writing: $!");
+    my $bagit_path = File::Spec->catfile( $metadata_path, "bagit.txt");
+    open(my $BAGIT, ">:encoding(UTF-8)", $bagit_path) or croak("Can't open $bagit_path for writing: $!");
     print($BAGIT "BagIt-Version: 1.0\nTag-File-Character-Encoding: UTF-8");
     close($BAGIT);
     return 1;
@@ -813,8 +813,8 @@ sub create_baginfo {
     $self->add_or_replace_baginfo_by_key('Bag-Size', $self->calc_bagsize());
     # The RFC does not allow reordering:
     my $metadata_path = $self->metadata_path();
-    my $bag_info_path = File::Spec->catdir( $metadata_path, "bag-info.txt");
-    open(my $BAGINFO, ">", $bag_info_path) or croak("Can't open $bag_info_path for writing: $!");
+    my $bag_info_path = File::Spec->catfile( $metadata_path, "bag-info.txt");
+    open(my $BAGINFO, ">:encoding(UTF-8)", $bag_info_path) or croak("Can't open $bag_info_path for writing: $!");
     foreach my $entry (@{ $self->bag_info() }) {
         my %tmp = %{ $entry };
         my ($key, $value) = %tmp;
@@ -901,7 +901,7 @@ Archive::BagIt::Base - The common base for Archive::BagIt. This is the module fo
 
 =head1 VERSION
 
-version 0.062
+version 0.063
 
 =head1 SYNOPSIS
 
@@ -951,7 +951,7 @@ Archive::BagIt::Base - The common base for Archive::BagIt. This is the module fo
 
 =head1 VERSION
 
-version 0.062
+version 0.063
 
 =head1 NAME
 
