@@ -48,7 +48,7 @@ sub get_hash_string {
 
 sub verify_file {
     my ($self, $filename) = @_;
-    open(my $fh, '<', $filename) || croak ("Can't open '$filename', $!");
+    open(my $fh, '<:raw', $filename) || croak ("Can't open '$filename', $!");
     binmode($fh);
     my $digest = $self->get_hash_string($fh);
     close $fh || croak("could not close file '$filename', $!");
@@ -69,7 +69,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin (d
 
 =head1 VERSION
 
-version 0.062
+version 0.063
 
 =head1 NAME
 
@@ -77,7 +77,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin (d
 
 =head1 VERSION
 
-version 0.062
+version 0.063
 
 =head1 AVAILABILITY
 
